"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const backtrace_node_1 = require("backtrace-node");
const util_1 = __importDefault(require("util"));
const winston_1 = __importStar(require("winston"));
class Logger {
    constructor(optionsOrLevel, options) {
        // transportLevel definition that Logger class respect:
        // #define SD_EMERG   "<0>"  /* system is unusable */
        // #define SD_ALERT   "<1>"  /* action must be taken immediately */
        // #define SD_CRIT    "<2>"  /* critical conditions */
        // #define SD_ERR     "<3>"  /* error conditions */
        // #define SD_WARNING "<4>"  /* warning conditions */
        // #define SD_NOTICE  "<5>"  /* normal but significant condition */
        // #define SD_INFO    "<6>"  /* informational */
        // #define SD_DEBUG   "<7>"  /* debug-level messages */
        this.transportLevel = {
            error: 3,
            warn: 4,
            info: 5,
            verbose: 6,
            debug: 7,
            silly: 6,
        };
        if (typeof optionsOrLevel === 'string') {
            this.options = Object.assign(this.defaultOptions(), options);
            this.options.logLevel = optionsOrLevel;
        }
        else {
            this.options = Object.assign(this.defaultOptions(), optionsOrLevel);
        }
        (0, winston_1.configure)({
            format: winston_1.format.combine(winston_1.format.colorize(), winston_1.format.printf(({ level, message }) => {
                const date = new Date().toLocaleString();
                const result = `${level}: ` +
                    `<${this.getTransportLevel()}>` +
                    `${this.options.logLevel}:[${date}] ${message}`;
                if (!this.options.newline) {
                    return result.replace(/\n+/g, ' ').replace(/\r+/g, ' ');
                }
                return result;
            })),
            transports: new winston_1.transports.Console({
                level: this.options.logLevel,
                silent: process.env.NODE_ENV === 'test',
            }),
        });
        Logger._logger = this;
    }
    static getLogger() {
        if (!Logger._logger) {
            this._logger = new Logger();
            this._logger.warn(`Creating new default logger instance`);
        }
        return this._logger;
    }
    /**
     * overrides the default logger instance or set the existing one.
     * @param logger the logger instance.
     */
    static setLogger(logger) {
        this._logger = logger;
    }
    static initializeBacktrace(opts) {
        if (!opts || !opts.endpoint) {
            return;
        }
        const logger = this.getLogger();
        logger.debug('Initializing backtrace-node integration');
        const client = (0, backtrace_node_1.initialize)(opts);
        if (!client) {
            logger.debug('Cannot initialize Backtrace integration. Please verify Backtrace url');
        }
    }
    trace(errorOrData, ...data) {
        this.log('verbose', errorOrData, ...data);
    }
    info(errorOrData, ...data) {
        this.log('info', errorOrData, ...data);
    }
    warn(errorOrData, ...data) {
        this.log('warn', errorOrData, ...data);
    }
    debug(errorOrData, ...data) {
        this.log('debug', errorOrData, ...data);
    }
    error(errorOrData, ...data) {
        const exception = errorOrData instanceof Error ? errorOrData : new Error(errorOrData);
        let attributes;
        if (data &&
            data.length > 0 &&
            data[0] instanceof Object &&
            !Array.isArray(data[0])) {
            attributes = data[0];
            data.shift();
        }
        this.log('error', errorOrData, ...data);
        const client = (0, backtrace_node_1.getBacktraceClient)();
        if (client) {
            client.reportSync(exception, attributes);
        }
    }
    log(level, errorOrData, ...args) {
        if (errorOrData instanceof Error) {
            if (args && args.length) {
                winston_1.default.log({
                    level,
                    message: util_1.default.format(args.shift(), ...args, this.options.stackTrace
                        ? errorOrData
                        : `Error: ${errorOrData.message}`),
                });
            }
            else {
                winston_1.default.log({
                    level,
                    message: util_1.default.format(this.options.stackTrace ? errorOrData : errorOrData.message),
                });
            }
        }
        else {
            winston_1.default.log({
                level,
                message: util_1.default.format(errorOrData, ...args),
            });
        }
    }
    getTransportLevel() {
        return (this.transportLevel[this.options.logLevel] || this.transportLevel['debug']);
    }
    defaultOptions() {
        return {
            logLevel: 'debug',
            newline: false,
            stackTrace: false,
        };
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map