"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UniverseHelper = exports.http = exports.https = void 0;
const url = __importStar(require("url"));
exports.https = 'https://';
exports.http = 'http://';
/**
 * Backtrae universe utils
 */
class UniverseHelper {
    /**
     * return Backtrace host url
     * @param urlString sample url to any Backtrace resource
     * Example:
     * https://yolo.sp.backtrace.io => https://yolo.sp.backtrace.io
     * https://sampleHostName.backtrace.io/blah/poop/doop => https://sampleHostName.backtrace.io
     */
    static getBacktraceHostName(urlString) {
        if (!urlString) {
            return undefined;
        }
        const obj = url.parse(urlString);
        return `${obj.protocol}//${obj.hostname}`;
    }
    /**
     * Get an universe name from Backtrace url.
     * @param urlString sample url to any Backtrace resource
     * Example:
     * https://yolo.sp.backtrace.io => yolo
     * https://sampleHostName.backtrace.io => sampleHostName
     */
    static getBacktaceUniverseName(urlString) {
        if (!urlString) {
            return undefined;
        }
        const hostNameIndexEnd = urlString.indexOf('backtrace.io');
        if (hostNameIndexEnd === -1) {
            return undefined;
        }
        return urlString.includes('submit.sp.backtrace.io')
            ? urlString.substring(hostNameIndexEnd, urlString.indexOf('/', hostNameIndexEnd))
            : urlString.substring(urlString.indexOf('//') + 2, urlString.indexOf('.sp.backtrace.io'));
    }
    static getBacktaceUniverseNameFromConf(conf) {
        const universeName = conf.universe.name;
        if (!universeName || conf.universe.deleted !== 0) {
            throw new Error('cannot find universe');
        }
        return universeName;
    }
    static removeProtocol(str) {
        if (str.startsWith(exports.https)) {
            return str.substring(exports.https.length);
        }
        if (str.startsWith(exports.http)) {
            return str.substring(exports.http.length);
        }
        return str;
    }
    // Abstraction in case it needs to be extended in future
    static normalizeUrl(str) {
        return this.removeProtocol(str);
    }
}
exports.UniverseHelper = UniverseHelper;
//# sourceMappingURL=backtraceUniverseHelper.js.map